#
# spec file for package python-Authlib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname authlib
%{?sle15_python_module_pythons}
Name:           python-Authlib
Version:        1.5.2
Release:        1.1
Summary:        Python library for building OAuth and OpenID Connect servers
License:        BSD-3-Clause
URL:            https://authlib.org/
Source:         https://github.com/lepture/%{modname}/archive/refs/tags/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module anyio}
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module Flask-SQLAlchemy}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module cachelib}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module starlette}
BuildRequires:  %{python_module typing_extensions}
# /SECTION
BuildRequires:  fdupes
Requires:       python-cryptography
Suggests:       python-requests
BuildArch:      noarch
%python_subpackages

%description
A Python library for building OAuth and OpenID Connect servers.

%prep
%autosetup -p1 -n %{modname}-%{version}
# Remove the file containing the commercial license so licensedigger
# doesn't complain about the dual license
rm COMMERCIAL-LICENSE

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib} PYTHONDONTWRITEBYTECODE=1
$python -mpytest tests/core
$python -mpytest tests/flask
# gh#lepture/authlib#456
$python -mpytest tests/jose -k 'not (test_dir_alg_xc20p or test_xc20p_content_encryption_decryption)'
export DJANGO_SETTINGS_MODULE=tests.clients.test_django.settings
$python -mpytest tests/clients
# export DJANGO_SETTINGS_MODULE=tests.django.settings
# $python -mpytest tests/django
}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/%{modname}
%{python_sitelib}/[Aa]uthlib-%{version}.dist-info

%changelog
* Wed Apr 23 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.5.2
  * Forbid fragments in ``redirect_uris``. :issue:`714`
  * Fix invalid characters in ``error_description``. :issue:`720`
  * Add ``claims_cls``` parameter for client's ``parse_id_token``
    method. :issue:`725`
* Mon Apr 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Sun Mar 23 2025 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
  * Fix RFC9207 iss parameter.
  * Fix token introspection auth method for clients.
  * Optional typ claim in JWT tokens.
  * JWT validation leeway.
  * Implement server-side :rfc:`RFC9207 <9207>`.
  * generate_id_token can take a kid parameter.
  * More detailed InvalidClientError.
  * OpenID Connect Dynamic Client Registration implementation.
* Thu Feb  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.4.1
  * Improve garbage collection on OAuth clients. (#698)
  * Fix client parameters for httpx. (#694)
* Fri Jan 24 2025 ecsos <ecsos@opensuse.org>
- Update to 1.4.0
  * Fix id_token decoding when kid is null. :pr:`659`
  * Support for Python 3.13. :pr:`682`
  * Force login if the prompt parameter value is login. :pr:`637`
  * Support for httpx 0.28, :pr:`695`
  * Breaking changes:
  - Stop support for Python 3.8. :pr:`682`
- Drop py313-tests.patch, because now in upstream.
- Drop httpx028.patch, because now in upstream.
* Thu Dec 19 2024 Markéta Machová <mmachova@suse.com>
- Add httpx028.patch to add compatibility with new httpx
* Thu Oct 31 2024 Dirk Müller <dmueller@suse.com>
- add py313-tests.patch
- modernize spec file
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Prevent ever-growing session size for OAuth clients.
  * Revert quote client id and secret.
  * unquote basic auth header for authorization server.
* Mon Jun 10 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.3.1 (CVE-2024-37568, bsc#1226138):
  * Prevent OctKey to import ssh and PEM strings.
* Tue Jan 23 2024 Antonio Larrosa <alarrosa@suse.com>
- Remove the file containing a Commercial license otherwise
  licensedigger rejects the dual-licensed package.
  See https://docs.authlib.org/en/latest/community/licenses.html .
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Restore AuthorizationServer.create_authorization_response
    behavior, via :PR:`558`
  * Include leeway in validate_iat() for JWT, via :PR:`565`
  * Fix encode_client_secret_basic, via :PR:`594`
  * Use single key in JWK if JWS does not specify kid, via
    :PR:`596`
  * Fix error when RFC9068 JWS has no scope field, via :PR:`598`
  * Get werkzeug version using importlib, via :PR:`591`
  * New features:
  * RFC9068 implementation, via :PR:`586`, by @azmeuk.
  * Breaking changes:
  * End support for python 3.7
* Sun Jun 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Apply headers in ``ClientSecretJWT.sign`` method
  * Allow falsy but non-None grant uri params
  * Fixed ``authorize_redirect`` for Starlette v0.26.0
  * Removed ``has_client_secret`` method and documentation
  * Removed ``request_invalid`` and ``token_revoked`` remaining
    occurences and documentation.
  * Fixed RFC7591 ``grant_types`` and ``response_types`` default
    values
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.2.0
  * Not passing request.body to ResourceProtector, #485.
  * Use flask.g instead of _app_ctx_stack, #482.
  * Add headers parameter back to ClientSecretJWT, #457.
  * Always passing realm parameter in OAuth 1 clients, #339.
  * Implemented RFC7592 Dynamic Client Registration Management Protocol, #505`
  * Add default_timeout for requests OAuth2Session and AssertionSession.
  * Deprecate jwk.loads and jwk.dumps
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 1.1.0
  * This release contains breaking changes and security fixes.
  * Allow to pass claims_options to Framework OpenID Connect clients, via PR#446.
  * Fix .stream with context for HTTPX OAuth clients, via PR#465.
  * Fix Starlette OAuth client for cache store, via PR#478.
* Thu Aug  4 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on mock.
- Remove duplicated BuildRequires on pytest.
* Mon May  9 2022 Matej Cepl <mcepl@suse.com>
- Fix tests.
* Thu Apr 21 2022 Michael Ströder <michael@stroeder.com>
- Update to 1.0.1
  * Fix authenticate_none method, via #438.
  * Allow to pass in alternative signing algorithm to RFC7523 authentication methods via #447.
  * Fix missing_token for Flask OAuth client, via #448.
  * Allow openid in any place of the scope, via #449.
  * Security fix for validating essential value on blank value in JWT, via #445.
- Update to 1.0.0
  * Dropped support for Python 2
  * Removed built-in SQLAlchemy integration.
  * The whole framework client integrations have been restructured
* Tue Nov 16 2021 Michael Ströder <michael@stroeder.com>
- Update to 0.15.5
  * Make Authlib compatible with latest httpx
  * Make Authlib compatible with latest werkzeug
  * Allow customize RFC7523 alg value
* Fri Aug 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.15.4
  * Security fix when JWT claims is None.
* Mon Aug  9 2021 Jan Engelhardt <jengelh@inai.de>
- Drop filler wording from description again.
* Tue Mar 23 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.15.3
  https://docs.authlib.org/en/latest/changelog.html#version-0-15-3
  https://docs.authlib.org/en/latest/changelog.html#version-0-15-2
  https://docs.authlib.org/en/latest/changelog.html#version-0-15-1
  https://docs.authlib.org/en/latest/changelog.html#version-0-15
* Wed Aug  5 2020 Stasiek Michalski <stasiek@michalski.cc>
- Initial package
